pub struct IdentityServiceToken;Expand description
Authentication is required by including an identity server access token in the
Authentication http header, or an access_token query parameter.
Using the query parameter is deprecated since Matrix 1.11.